==> igniteui-react-16.16.2.tgz: package/esm2015/lib/ButtonBase.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { BaseElement } from "./BaseElement";
import { WCNativeHelper } from "./WCNativeHelper";
import { enumGetBox, EnumUtil, markType } from "igniteui-react-core";
import { ButtonBaseType_$type } from "./ButtonBaseType";
import { ButtonBaseTarget_$type } from "./ButtonBaseTarget";
import { SizableComponentSize_$type } from "./SizableComponentSize";
import { VoidEventArgs } from "./VoidEventArgs";
/**
 * @hidden
 */
export let ButtonBase = /*@__PURE__*/ (() => {
    class ButtonBase extends BaseElement {
        constructor() {
            super(...arguments);
            this.clicked = null;
            this.g = new WCNativeHelper();
            this.j = null;
            this.focus = null;
            this.blur = null;
        }
        clickedChanged() {
            if (this.clicked != null) {
                this.h.g("click", (a) => this.clicked(this, VoidEventArgs.b(a)), false);
            }
            else {
                this.h.h("click");
            }
        }
        get h() {
            return this.g;
        }
        get nativeElement() {
            return this.j;
        }
        set nativeElement(a) {
            this.j = a;
            this.g.d = this.j;
        }
        get b() {
            let ret_ = this.h.c("type");
            ret_ = enumGetBox(ButtonBaseType_$type, EnumUtil.getEnumValue(ButtonBaseType_$type, EnumUtil.parse(ButtonBaseType_$type, ret_.toString(), true)));
            return EnumUtil.getEnumValue(ButtonBaseType_$type, ret_);
        }
        set b(a) {
            let value_ = enumGetBox(ButtonBaseType_$type, a);
            value_ = WCNativeHelper.e(value_.toString());
            this.h.i("type", value_);
        }
        get n() {
            let ret_ = this.h.c("href");
            return ret_;
        }
        set n(a) {
            let value_ = a;
            this.h.i("href", value_);
        }
        get m() {
            let ret_ = this.h.c("download");
            return ret_;
        }
        set m(a) {
            let value_ = a;
            this.h.i("download", value_);
        }
        get a() {
            let ret_ = this.h.c("target");
            ret_ = enumGetBox(ButtonBaseTarget_$type, EnumUtil.getEnumValue(ButtonBaseTarget_$type, EnumUtil.parse(ButtonBaseTarget_$type, ret_.toString(), true)));
            return EnumUtil.getEnumValue(ButtonBaseTarget_$type, ret_);
        }
        set a(a) {
            let value_ = enumGetBox(ButtonBaseTarget_$type, a);
            value_ = WCNativeHelper.e(value_.toString());
            this.h.i("target", value_);
        }
        get o() {
            let ret_ = this.h.c("rel");
            return ret_;
        }
        set o(a) {
            let value_ = a;
            this.h.i("rel", value_);
        }
        get i() {
            let ret_ = this.h.c("disabled");
            return ret_;
        }
        set i(a) {
            let value_ = a;
            this.h.i("disabled", value_);
        }
        get l() {
            let ret_ = this.h.c("ariaLabel");
            return ret_;
        }
        set l(a) {
            let value_ = a;
            this.h.i("ariaLabel", value_);
        }
        get c() {
            let ret_ = this.h.c("size");
            ret_ = enumGetBox(SizableComponentSize_$type, EnumUtil.getEnumValue(SizableComponentSize_$type, EnumUtil.parse(SizableComponentSize_$type, ret_.toString(), true)));
            return EnumUtil.getEnumValue(SizableComponentSize_$type, ret_);
        }
        set c(a) {
            let value_ = enumGetBox(SizableComponentSize_$type, a);
            value_ = WCNativeHelper.e(value_.toString());
            this.h.i("size", value_);
        }
        focusChanged() {
            if (this.focus != null) {
                this.h.g("focus", (a) => this.focus(this, VoidEventArgs.b(a)));
            }
            else {
                this.h.h("focus");
            }
        }
        blurChanged() {
            if (this.blur != null) {
                this.h.g("blur", (a) => this.blur(this, VoidEventArgs.b(a)));
            }
            else {
                this.h.h("blur");
            }
        }
        t(a) {
            this.nativeElement.focusComponent(a);
        }
        q() {
            this.nativeElement.blurComponent();
        }
    }
    ButtonBase.$t = /*@__PURE__*/ markType(ButtonBase, 'ButtonBase', BaseElement.$);
    return ButtonBase;
})();

==> igniteui-react-18.5.1.tgz: package/esm2015/lib/ButtonBase.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { BaseElement } from "./BaseElement";
import { WCNativeHelper } from "./WCNativeHelper";
import { enumGetBox, EnumUtil, markType } from "igniteui-react-core";
import { ButtonBaseType_$type } from "./ButtonBaseType";
import { ButtonBaseTarget_$type } from "./ButtonBaseTarget";
import { SizableComponentSize_$type } from "./SizableComponentSize";
import { VoidEventArgs } from "./VoidEventArgs";
/**
 * @hidden
 */
export let ButtonBase = /*@__PURE__*/ (() => {
    class ButtonBase extends BaseElement {
        constructor() {
            super(...arguments);
            this.clicked = null;
            this.g = new WCNativeHelper();
            this.j = null;
            this.focus = null;
            this.blur = null;
        }
        clickedChanged() {
            if (this.clicked != null) {
                this.h.r("click", (a) => this.clicked(this, VoidEventArgs.b(a)), false);
            }
            else {
                this.h.u("click");
            }
        }
        get h() {
            return this.g;
        }
        get nativeElement() {
            return this.j;
        }
        set nativeElement(a) {
            this.j = a;
            this.g.o = this.j;
        }
        setNativeElement(a) {
            this.nativeElement = a;
        }
        get b() {
            let ret_ = this.h.n("type");
            ret_ = enumGetBox(ButtonBaseType_$type, EnumUtil.getEnumValue(ButtonBaseType_$type, this.h.f(ButtonBaseType_$type, ret_)));
            return EnumUtil.getEnumValue(ButtonBaseType_$type, ret_);
        }
        set b(a) {
            let value_ = enumGetBox(ButtonBaseType_$type, a);
            value_ = WCNativeHelper.p(value_.toString());
            this.h.v("type", value_);
        }
        get n() {
            let ret_ = this.h.n("href");
            return ret_;
        }
        set n(a) {
            let value_ = a;
            this.h.v("href", value_);
        }
        get m() {
            let ret_ = this.h.n("download");
            return ret_;
        }
        set m(a) {
            let value_ = a;
            this.h.v("download", value_);
        }
        get a() {
            let ret_ = this.h.n("target");
            ret_ = enumGetBox(ButtonBaseTarget_$type, EnumUtil.getEnumValue(ButtonBaseTarget_$type, this.h.f(ButtonBaseTarget_$type, ret_)));
            return EnumUtil.getEnumValue(ButtonBaseTarget_$type, ret_);
        }
        set a(a) {
            let value_ = enumGetBox(ButtonBaseTarget_$type, a);
            value_ = WCNativeHelper.p(value_.toString());
            this.h.v("target", value_);
        }
        get o() {
            let ret_ = this.h.n("rel");
            return ret_;
        }
        set o(a) {
            let value_ = a;
            this.h.v("rel", value_);
        }
        get i() {
            let ret_ = this.h.n("disabled");
            return ret_;
        }
        set i(a) {
            let value_ = a;
            this.h.v("disabled", value_);
        }
        get l() {
            let ret_ = this.h.n("ariaLabel");
            return ret_;
        }
        set l(a) {
            let value_ = a;
            this.h.v("ariaLabel", value_);
        }
        get c() {
            let ret_ = this.h.n("size");
            ret_ = enumGetBox(SizableComponentSize_$type, EnumUtil.getEnumValue(SizableComponentSize_$type, this.h.f(SizableComponentSize_$type, ret_)));
            return EnumUtil.getEnumValue(SizableComponentSize_$type, ret_);
        }
        set c(a) {
            let value_ = enumGetBox(SizableComponentSize_$type, a);
            value_ = WCNativeHelper.p(value_.toString());
            this.h.v("size", value_);
        }
        focusChanged() {
            if (this.focus != null) {
                this.h.r("focus", (a) => this.focus(this, VoidEventArgs.b(a)));
            }
            else {
                this.h.u("focus");
            }
        }
        blurChanged() {
            if (this.blur != null) {
                this.h.r("blur", (a) => this.blur(this, VoidEventArgs.b(a)));
            }
            else {
                this.h.u("blur");
            }
        }
        t(a) {
            this.nativeElement.focus(this.h.i(a));
        }
        q() {
            this.nativeElement.blur();
        }
    }
    ButtonBase.$t = /*@__PURE__*/ markType(ButtonBase, 'ButtonBase', BaseElement.$);
    return ButtonBase;
})();
